@@ -311,7 +311,7 @@ static gint add_buddy_cb(fetion_account *ses, const gchar *sipmsg, struct transa
 
 static gint handle_contact_cb(fetion_account *UNUSED(ac), const gchar *sipmsg, struct transaction *UNUSED(trans))
 {
-	purple_debug_info("fetion", "%s\n", sipmsg);
+	purple_debug_info("fetion", "%s", sipmsg);
 	return 0;
 }
 
