@@ -112,11 +112,11 @@ char* generate_response(const char* nouce , const char* userid
 //	RSA_print_fp(stdout, r, 5);
 	flen = RSA_size(r);
 	out =  (guchar*)g_malloc0(flen);
-	purple_debug_info("fetion", "start encrypting response\n");
+	purple_debug_info("fetion", "start encrypting response");
 	ret = RSA_public_encrypt(nonce_len + aeskey_len + psd_len,
 			res , out, r, RSA_PKCS1_PADDING);
 	if (ret < 0){
-		purple_debug_info("fetion", "encrypt response failed!\n");
+		purple_debug_info("fetion", "encrypt response failed!");
 		g_free(res); 
 		g_free(aeskey);
 		g_free(psd);
@@ -124,7 +124,7 @@ char* generate_response(const char* nouce , const char* userid
 		return NULL;
 	}
 	RSA_free(r);
-	purple_debug_info("fetion", "encrypting reponse success\n");
+	purple_debug_info("fetion", "encrypting reponse success");
 	g_free(res); 
 	g_free(aeskey);
 	g_free(psd);
@@ -206,16 +206,13 @@ static gint pic_read_cb(gpointer data, gint source, const gchar *UNUSED(message)
 			ac->data = (gchar*)0;
 			return -1;
 		}
-
-		purple_debug_info("fetion", "recv:\n%s\n", ac->data);
-
 		doc = xmlParseMemory(pos + 4, strlen(pos + 4));
 		node = xmlDocGetRootElement(doc);
 		node = node->xmlChildrenNode;
 		ac->user->verification->guid = (gchar*)xmlGetProp(node , BAD_CAST "id");
 		code = (gchar*)xmlGetProp(node , BAD_CAST "pic");
 		xmlFreeDoc(doc);
-		purple_debug_info("fetion", "Generating verification code picture\n");
+		purple_debug_info("fetion", "Generating verification code picture");
 		pic = decode_base64(code , &piclen);
 		g_free(code);
 		fetion_code_request(ac, pic, piclen);
@@ -248,8 +245,6 @@ static gint pic_code_cb(gpointer data, gint source, const gchar *UNUSED(message)
 		    "Connection: close\r\n\r\n",
 		   	user->verification->algorithm == NULL ? "" : user->verification->algorithm,
 		   	user->ssic == NULL ? "" : cookie, NAV_SERVER);
-
-	purple_debug_info("fetion", "send:\n%s\n", http);
 	
 	if(send(source, http, strlen(http), 0) == -1) return -1;
 	ac->data = (gchar*)0;
@@ -268,7 +263,7 @@ gboolean ssi_auth_action(gpointer data, PurpleSslConnection * gsc, gint UNUSED(c
 	fetion_account *ac = (fetion_account*)data;
 	User *user = ac->user;
 	
-	purple_debug_info("fetion", "initialize ssi authentication action\n");
+	purple_debug_info("fetion", "initialize ssi authentication action");
 	password = hash_password_v4(user->userId , user->password);
 	memset(noUri, 0, sizeof(noUri));
 	if(user->loginType == LOGIN_TYPE_MOBILENO)
@@ -338,8 +333,6 @@ static gint sipc_aut_cb(gpointer data, gint source, const gchar *UNUSED(error_me
 	guint  length = 0;
 	gint   group_count, buddy_count;
 	PurpleConnection *pc;
-	PurplePresence *presence;
-	const gchar *status_id;
 	fetion_account *ac = (fetion_account*)data;
 
 	if((n = recv(source, sipmsg, sizeof(sipmsg) - 1, 0)) == -1)	return -1;
@@ -400,11 +393,6 @@ aut_fin:
 
 	purple_connection_set_state(pc, PURPLE_CONNECTED);
 
-	presence = purple_account_get_presence(ac->account);
-	status_id = get_status_id(ac->user->state);
-	if(ac->user->state == 0) status_id = "Hidden";
-	purple_presence_set_status_active(presence, status_id, TRUE);
-
 	fx_blist_init(ac);
 
 	if(fetion_contact_subscribe_only(source, ac->user) == -1) return -1;
@@ -426,7 +414,7 @@ static gint sipc_reg_action(gpointer data, gint source, const gchar *UNUSED(erro
 
 	fetion_sip* sip = fetion_sip_new0(ac->user);
 
-	purple_debug_info("fetion", "initialize sipc registeration action\n");
+	purple_debug_info("fetion", "initialize sipc registeration action");
 
 	fetion_sip_set_type(sip , SIP_REGISTER);
 	SipHeader* cheader = fetion_sip_header_new("CN" , cnouce);
@@ -435,7 +423,7 @@ static gint sipc_reg_action(gpointer data, gint source, const gchar *UNUSED(erro
 	fetion_sip_add_header(sip , client);
 	g_free(cnouce);
 	sipmsg = fetion_sip_to_string(sip , NULL);
-	purple_debug_info("fetion", "start registering to sip server(%s:%d)\n"
+	purple_debug_info("fetion", "start registering to sip server(%s:%d)"
 			 , ac->user->sipcProxyIP , ac->user->sipcProxyPort);
 	if((ret = write(source , sipmsg , strlen(sipmsg))) == -1) return -1;
 	g_free(sipmsg);
@@ -454,7 +442,7 @@ gint sipc_aut_action(gint sk, fetion_account *ac, const gchar *response)
 	SipHeader* ackheader = NULL;
 	fetion_sip* sip = ac->user->sip;
 
-	purple_debug_info("fetion", "Initialize sipc authencation action\n");
+	purple_debug_info("fetion", "Initialize sipc authencation action");
 
 	xml = generate_auth_body(user);
 	fetion_sip_set_type(sip , SIP_REGISTER);
@@ -473,7 +461,7 @@ gint sipc_aut_action(gint sk, fetion_account *ac, const gchar *response)
 
 	fetion_verification_free(user->verification);
 	user->verification = NULL;
-	purple_debug_info("fetion", "Start sipc authentication , with ak-value\n");
+	purple_debug_info("fetion", "Start sipc authentication , with ak-value");
 
 	if(send(sk, sipmsg, strlen(sipmsg), 0) == -1) { g_free(sipmsg); return -1; }
 	g_free(sipmsg);
@@ -530,10 +518,10 @@ static void ssi_auth_cb(gpointer data, PurpleSslConnection *source, PurpleInputC
 	if(atoi(pos) == 200) {
 		fetion_verification_free(user->verification);
 		user->verification = NULL;
-		purple_debug_info("fetion", "ssi login success\n");
+		purple_debug_info("fetion", "ssi login success");
 		parse_ssi_auth_success(node , user);
 	} else {
-		purple_debug_info("fetion", "ssi login failed , status-code :%s\n" , pos);
+		purple_debug_info("fetion", "ssi login failed , status-code :%s" , pos);
 		parse_ssi_auth_failed(node , user);
 		g_free(pos);
 		xmlFreeDoc(doc);
@@ -593,8 +581,8 @@ static void parse_sipc_reg_response(const gchar *reg_response, gchar **nouce, gc
 	*key = (gchar*)g_malloc0(n + 1);
 	strncpy(*key , pos , n);
 	(*key)[n] = '\0';
-	purple_debug_info("fetion", "register to sip server success\n");
-	purple_debug_info("fetion", "nonce:%s\n" , *nouce);
+	purple_debug_info("fetion", "register to sip server success");
+	purple_debug_info("fetion", "nonce:%s" , *nouce);
 }
 static void parse_sms_frequency(xmlNodePtr node , User *user)
 {
@@ -664,7 +652,7 @@ static gint cfg_cb(gpointer data, gint source, const gchar *UNUSED(error_message
 							(PurpleProxyConnectFunction)sipc_reg_action, ac);
 
 		if(!ac->conn_data) {
-			purple_debug_error("fetion", "connect to ssi server failed\n");
+			purple_debug_error("fetion", "connect to ssi server failed");
 			purple_connection_error_reason(ac->gc,
 				       PURPLE_CONNECTION_ERROR_AUTHENTICATION_FAILED,
 							       _("Login Failed."));
@@ -692,7 +680,6 @@ static gint download_cfg(gpointer data, gint source, const gchar *UNUSED(error_m
 				   "Connection: Close\r\n"
 				   "Content-Length: %d\r\n\r\n%s",
 				   uri , strlen(body) , body);
-	purple_debug_info("fetion", "send:\n%s\n", http);
 	g_free(body);
 	if(send(source, http, strlen(http), 0) == -1) return -1;
 	ac->data = (gchar*)0;
@@ -718,7 +705,7 @@ static gint parse_sipc_auth_response(const gchar *auth_response, User *user, gin
 	if(code == 200){
 		fetion_verification_free(user->verification);
 		user->verification = NULL;
-		purple_debug_info("fetion", "sipc authentication success\n");
+		purple_debug_info("fetion", "sipc authentication success");
 	}else if(code == 421 || code == 420){
 		parse_sipc_verification(user , auth_response);
 		return 2;
@@ -811,12 +798,12 @@ static gchar* generate_auth_body(User* user)
 	xmlNewProp(node , BAD_CAST "mobile-no" , BAD_CAST user->mobileno);
 	xmlNewProp(node , BAD_CAST "user-id" , BAD_CAST user->userId);
 	node1 = xmlNewChild(node , NULL , BAD_CAST "personal" , NULL);
-	xmlNewProp(node1 , BAD_CAST "version" , BAD_CAST user->personalVersion);
+	xmlNewProp(node1 , BAD_CAST "version" , BAD_CAST "0"/*user->personalVersion*/);
 	xmlNewProp(node1 , BAD_CAST "attributes" , BAD_CAST "v4default");
 	node1 = xmlNewChild(node , NULL , BAD_CAST "custom-config" , NULL);
-	xmlNewProp(node1 , BAD_CAST "version" , BAD_CAST user->customConfigVersion);
+	xmlNewProp(node1 , BAD_CAST "version" , BAD_CAST "0"/*user->customConfigVersion*/);
 	node1 = xmlNewChild(node , NULL , BAD_CAST "contact-list" , NULL);
-	xmlNewProp(node1 , BAD_CAST "version" , BAD_CAST user->contactVersion);
+	xmlNewProp(node1 , BAD_CAST "version" , BAD_CAST "0"/*user->contactVersion*/);
 	xmlNewProp(node1 , BAD_CAST "buddy-attributes" , BAD_CAST "v4default");
 	node = xmlNewChild(rootnode , NULL , BAD_CAST "credentials" , NULL);
 	xmlNewProp(node , BAD_CAST "domains" , BAD_CAST "fetion.com.cn");
@@ -914,7 +901,7 @@ static void parse_contact_list(xmlNodePtr node, User* user,
 	*buddy_count = 0;
 
 	buf = xmlGetProp(node , BAD_CAST "version");
-	purple_debug_info("fetion", "start reading contact list\n");
+	purple_debug_info("fetion", "start reading contact list ");
 	if(strcmp(user->contactVersion , (char*) buf) == 0)
 		return;
 	strcpy(user->contactVersion , (char*)buf);
@@ -1028,7 +1015,7 @@ static void parse_contact_list(xmlNodePtr node, User* user,
 	}
 
 	*buddy_count = nr;
-	purple_debug_info("fetion", "read contact list complete\n");
+	purple_debug_info("fetion", "read contact list complete");
 }
 
 
@@ -1187,7 +1174,7 @@ static gchar *decode_base64(const char* in , int* len)
 
 	n = strlen(in);
 	if(n % 4 != 0) {
-		purple_debug_error("fetion", "Try to decode a string which is not a base64 string(decode_base64)\n");
+		purple_debug_error("fetion", "Try to decode a string which is not a base64 string(decode_base64)");
 		return NULL;
 	}
 	n = n / 4 * 3;
