@@ -92,9 +92,6 @@ static void fx_tooltip_text(PurpleBuddy *buddy, PurpleNotifyUserInfo *user_info,
 	g_return_if_fail(buddy != NULL);
 
 	status = purple_presence_get_active_status(purple_buddy_get_presence(buddy));
-
-	g_return_if_fail(status != NULL);
-
 	impresa = purple_status_get_attr_string(status, "impresa");
 	sid = purple_status_get_attr_string(status, "fetionno");
 	mobileno = purple_status_get_attr_string(status, "mobileno");
@@ -288,12 +285,9 @@ static gchar *fx_status_text(PurpleBuddy *buddy)
 
 	presence = purple_buddy_get_presence(buddy);
 	status   = purple_presence_get_active_status(presence);
-
-	if(!status) return (gchar*)0;
-
 	msg = purple_status_get_attr_string(status, "impresa");
 	if(msg && *msg)	return g_markup_escape_text(msg, -1);
-	return (gchar*)0;
+	return NULL;
 }
 
 static void send_sms_cb(PurpleBuddy *buddy, const gchar *text)
@@ -458,9 +452,6 @@ static void process_info_cb(fetion_account *ses, const gchar *sipmsg)
 					   "I: %s \r\n"
 					   "Q: %s\r\n\r\n",
 					   sipuri , callid , seq);
-
-		purple_debug_info("fetion", "send:\n%s\n", buf);
-
 		send(ses->sk, buf, strlen(buf), 0);
 		sid = fetion_sip_get_sid_by_sipuri(sipuri);
 		purple_prpl_got_attention(ses->gc, sid, FETION_NUDGE);
@@ -472,9 +463,6 @@ static void process_push_cb(fetion_account *ses, const gchar *sipmsg)
 	gint type;
 	
 	type = fetion_sip_get_type(sipmsg);
-
-	purple_debug_info("fetion", "recv: \n%s\n", sipmsg);
-
 	switch(type){
 		case SIP_NOTIFICATION :	process_notify_cb(ses, sipmsg);		break;
 		case SIP_MESSAGE:		process_message_cb(ses, sipmsg);	break;
@@ -546,7 +534,7 @@ static void fx_login(PurpleAccount *account)
 	presence = purple_account_get_presence(account);
 
 	status_id = get_status_id(ac->user->state);
-	/* if(ac->user->state == 0) */ status_id = "Hidden";
+	if(ac->user->state == 0) status_id = "Hidden";
 	purple_presence_set_status_active(presence, status_id, TRUE);
 	purple_connection_update_progress(pc, "Connecting", 1, 2);
 	purple_ssl_connect(ac->account, SSI_SERVER,
